{% load i18n %}

{% trans "Edit" as edit_text %}
{% trans "Publish" as publish_text %}
{% trans "Delete" as delete_text %}
{% if request.user.is_superuser %}
<div class="ui sticky" style="width: 272px !important; height: 262.531px !important; left: 26px; float:left">
    <div class="ui compact vertical labeled icon menu" style="margin: 5px;">
        {% if object.publisher_public or object.published == False %}
        <a class="red item" href="{% url 'admin:djcms_blog_posttitle_change' object.title_id %}">
            <i class="edit icon"></i>{{edit_text}}</a>
        {% else %}
        <a class="red item" href="{% url 'admin:djcms_blog_posttitle_change' object.publisher_draft.id %}">
            <i class="edit icon"></i>{{edit_text}}</a>
        {% endif %}
        <a class="blue {% if object.published == False %}{% else %}disabled{% endif %} item" href="{% url 'admin:djcms_blog_post_changelist'%}">
            <i class="paper plane outline icon"></i>{{publish_text}}</a>
        <a class="blue {% if object.published == False %}{% else %}disabled{% endif %} item" href="{% url 'admin:djcms_blog_post_delete' object.id %}">
            <i class="times icon"></i>{{delete_text}}</a>
    </div>
</div>
{% endif %}