body {
    background-color: #FFFFFF;
}
h1 {
    font-size: 3rem;
    margin-bottom: 2rem;
}
h2 {
    font-size: 2.5rem;
}
h3 {
    font-size: 2rem;
}
h4 {
    font-size: 1.8rem;
}
code {
    font-family: Menlo,Consolas,Monaco,Lucida Console,Liberation Mono,DejaVu Sans Mono,Bitstream Vera Sans Mono,Courier New,monospace,sans-serif;
}
p code {
    background: #282a36;
    color: #ececec;
    vertical-align: middle;
    white-space: pre-wrap;
    font-size: 0.8em;
    line-height: 1em;
    border-radius: 4px 4px 4px 4px;
    -moz-border-radius: 4px 4px 4px 4px;
    -webkit-border-radius: 4px 4px 4px 4px;
    border: 1px solid #303030;
    padding: 0.2rem 0.3rem 0.1rem;
    
}
pre {
    overflow: initial;
}
a{
    color: rgb(70, 70, 70);
    transition: color 0.3s ease;
}
a:hover {
    color: #111;
}
a:active, a:hover {
    outline: 0;
}
article.post {
    margin-bottom: 2rem;
}
h2 {
    color: rgb(70, 70, 70);
    font-family: "Montserrat", sans-serif;
    font-size: 2.5rem;
}
.author-profile .author-image {
    position: relative;
    left: auto;
    top: auto;
    width: 150px;
    height: 150px;
    padding: 3px;
    margin: -100px auto 0 auto;
    box-shadow: none;
}
.author-profile .author-image .img {
    position: relative;
    display: block;
    width: 100%;
    height: 100%;
    background-size: cover;
    background-position: center center;
    border-radius: 100%;
    border: 3px solid white;
}
.author-meta {
    color: rgb(94, 94, 94);
    padding: 2rem;
    text-align: center;
}
.author-bio {
    color: rgb(126, 126, 126);
    font-family: "Lato", sans-serif;
    padding: 3rem;
}
.post-title {
    color: rgb(70, 70, 70);
    font-family: "Montserrat", sans-serif;
    font-size: 3.6rem;
    margin-top: 4rem;
    margin-bottom: 1rem !important;
}

.main.container {
    margin-top: 2em;
}

.main.menu {
    margin-top: 4em;
    border-radius: 0;
    border: none;
    box-shadow: none;
    transition: box-shadow 0.5s ease,
    padding 0.5s ease;
}

.overlay {
    float: left;
    margin: 0em 3em 1em 0em;
}

.overlay .menu {
    position: relative;
    left: 0;
    transition: left 0.5s ease;
}

.main.menu.fixed {
    background-color: #FFFFFF;
    border: 1px solid #DDD;
    box-shadow: 0px 3px 5px rgba(0, 0, 0, 0.2);
    z-index: 1000 !important;
}

.overlay.fixed .menu {
    left: 800px;
}

.text.container .left.floated.image {
    margin: 2em 2em 2em -4em;
}

.text.container .right.floated.image {
    margin: 2em -4em 2em 2em;
}

.ui.footer.segment {
    margin: 5em 0em 0em;
    padding: 5em 0em;
}

.always-top {
    z-index: 2000;
}

.ui.sticky.fixed.top {
    margin-top: 80px !important;
}

.main.menu.fixed {
    background-color: rgba(255, 255, 255, 0.85) !important;
}

.social-links {
    color: #ccc;
}

.social-links:hover {
    color: #fff;
}

.breadcrumb {
    margin-top: 30px !important;
    margin-bottom: 30px !important;
}

.hidden.menu {
    display: none;
}

.large.top {
    background: rgba(255, 255, 255, 0.7);
}

.ui.vertical.stripe {
    padding: 8em 0em;
}

.ui.vertical.stripe h3 {
    font-size: 2em;
}

.ui.vertical.stripe .button+h3,
.ui.vertical.stripe p+h3 {
    margin-top: 3em;
}

.ui.vertical.stripe .floated.image {
    clear: both;
}

.ui.vertical.stripe p {
    font-size: 1.33em;
}

.ui.vertical.stripe .horizontal.divider {
    margin: 3em 0em;
}

.quote.stripe.segment {
    padding: 0em;
}

.quote.stripe.segment .grid .column {
    padding-top: 5em;
    padding-bottom: 5em;
}

.footer.segment {
    padding: 5em 0em;
}

.secondary.pointing.menu .toc.item {
    display: none;
}

.logo {
    margin-left: 10px;
    margin-right: 10px;
    width: 50px;
    height: 50px;
}

.ui.sticky.fixed.top {
    margin-top: 80px !important;
}

.main.menu.fixed {
    background-color: rgba(255, 255, 255, 0.85);
}

hr {
    margin-top: 50px;
    margin-bottom: 50px;
    color: #ccc;
}

.blog-image {
    margin-top: 80px;
    max-width: 50%;
}

.blog-image--text {
    font-family: 'Lato', cursive !important;
    font-weight: 300 !important;
}

.blog-masterhead {
    display: flex !important;
    flex-direction: column;
    /* justify-content: left; */
    margin-top: 200px;
    padding: 4rem 0 4rem 0;
}
.author-masterhead {
    display: flex !important;
    flex-direction: column;
    /* justify-content: left; */
    margin-top: 0px;
    padding: 4rem 0 4rem 0;
}

.post-masterhead {
    display: flex !important;
    flex-direction: column;
    /* justify-content: left; */
    margin-top: 100px;
    padding: 4rem 0 4rem 0;
}

.typed-cursor {
    display: none;
    opacity: 0;
    -webkit-animation: blink 0.7s infinite;
    -moz-animation: blink 0.7s infinite;
    animation: blink 0.7s infinite;
}
.masterhead-nav a,
.secondary-nav a {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    position: relative;
    vertical-align: middle;
    line-height: 1;
    text-decoration: none;
    -webkit-tap-highlight-color: transparent;
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 auto;
    -ms-flex: 0 0 auto;
    flex: 0 0 auto;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    background: none;
    padding: 0.92857143em 1.14285714em;
    text-transform: none;
    font-weight: normal;
    -webkit-transition: background 0.1s ease, box-shadow 0.1s ease, color 0.1s ease;
    transition: background 0.1s ease, box-shadow 0.1s ease, color 0.1s ease;
}

.masterhead-nav a {
    border-bottom-color: transparent;
    border-bottom-style: solid;
    border-radius: 0em;
    display: flex;
    align-items: center;
    -webkit-align-self: flex-end;
    -ms-flex-item-align: end;
    align-self: flex-end;
    margin: 0em 0em -2px;
    padding: 0.85714286em 1.14285714em;
    border-bottom-width: 2px;
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease;
    color: rgba(255, 255, 255, 0.9) !important;
}

.secondary-nav a {
    color: rgba(0, 0, 0, 0.87);
}

.secondary-nav {
    background: rgba(255, 255, 255, 0.7) !important;
    -webkit-backdrop-filter: saturate(110%) blur(5px);
    backdrop-filter: saturate(110%) blur(5px);
}

.blog-content {
    padding: 0 10% 0 10%;
    padding-top: 112px;
    font-family: 'Merriweather', serif;
    letter-spacing: 0.01rem;
    font-size: 18px;
    letter-spacing: 0.1rem;
    line-height: 1.7rem;
}
.blog-content img {
    max-width: 100%;
    display: block;
    margin: auto;
}
.author-content {
    padding: 0 10% 0 10%;
    padding-top: 30px;
    font-family: 'Merriweather', serif;
    letter-spacing: 0.01rem;
    font-size: 18px;
    letter-spacing: 0.1rem;
    line-height: 1.7rem;
}

.blog-name {
    font-family: 'Montserrat', sans-serif;
    font-size: 5rem;
    letter-spacing: -8px;
    font-weight: 800 !important;
    max-width: 100%;
    display: flex;
    justify-content: center;
    flex-direction: column;
    text-align: center;
    text-shadow: 1px 1px 2px rgba(150, 150, 150, 0.7);
}
.blog-description {
    font-size: 1.5rem;
}
.post-description {
    font-size: 1.15rem;
    line-height: 1.7rem;
}
.post-meta {
    font-family: 'Montserrat', sans-serif;
    margin: 10px 0px 40px 0px;
    letter-spacing: 0rem;
    font-size: 1rem;
    letter-spacing: 0.1rem;
    line-height: 1.7rem;
}
.post-meta__user {

}
.post-meta__time {
    float: right;
}
.post > .share {
    margin-top: 2rem;
    margin-bottom: 2rem;
}
.share a.twitter {
    color: #1dcaff;
}
.share a.facebook {
    color: #3b5998;
}
.share a.google-plus {
    color: #d34836;
}
.share a.linkedin {
    color: #0077b5;
}
.share a:hover {
    color: #303030;
}
.post-meta__post_time {
    float: left;
    color: #7c7c7c;
    margin-right: 0.5rem;
}
.masthead {
    height: 700px !important;
}
.cms-content img {
    max-width: 100%;
    margin: auto;
}
.hljs {
    border-radius: 5px;
    padding: 25px !important;
}
@keyframes blink {
    0% {
        opacity: 1;
    }
    50% {
        opacity: 0;
    }
    100% {
        opacity: 1;
    }
}

@-webkit-keyframes blink {
    0% {
        opacity: 1;
    }
    50% {
        opacity: 0;
    }
    100% {
        opacity: 1;
    }
}

@-moz-keyframes blink {
    0% {
        opacity: 1;
    }
    50% {
        opacity: 0;
    }
    100% {
        opacity: 1;
    }
}

@keyframes cursor {
    0% {
        opacity: 0;
    }
    40% {
        opacity: 0;
    }
    50% {
        opacity: 1;
    }
    90% {
        opacity: 1;
    }
    100% {
        opacity: 0;
    }
}

@media only screen and (max-width: 700px) {
    .blog-masterhead {
        display: flex !important;
        flex-direction: column;
        text-align: center;
    }
    .blog-image {
        margin-top: 20px;
        margin: auto;
    }
    .blog-name {
        font-family: 'Montserrat', sans-serif;
        font-size: 5rem;
        letter-spacing: -8px;
        font-weight: 800 !important;
        font-style: normal;
        text-align: center;
        max-width: 100%;
        display: flex;
        justify-content: center;
        flex-direction: column;
        margin: auto;
        text-shadow: 1px 1px 2px rgba(0, 0, 0, 0.7);
    }
}