{% extends "djcms_blog/base_post.html" %}
{% load humanize %}
{% load markdownify %}

{% block title %}
{{object.title}}
{% endblock %}

{% block content %}
{{ object.body | markdown | safe }}
<div class="ui divider"></div>
<div class="post post-meta">
    <a class="post-meta__user" href="/author/{{object.author.slug}}">
        <img class="ui avatar image" src="{{object.author.image.url}}">{{post.author.user.username}}</a>
    {% for tag in object.get_tags %}
    <a href="/{{object.blog.slug}}/tag/{{tag.slug}}/" class="ui {{tag.color}} label">
        {{tag.name}}
        <div class="detail">{{tag.get_post_count}}</div>
    </a>
    {% endfor %}
    <div class="post-meta__time">{{ object.published_date|naturaltime }}</div>
    {% include "djcms_blog/post_share.html" %}
</div>
{% endblock content %}