{% load i18n %}

{% trans "Edit" as edit_text %}
{% trans "Add Post" as add_post %}
{% if request.user.is_superuser %}
<div class="ui sticky" style="width: 272px !important; height: 262.531px !important; left: 26px; float:left">
    <div class="ui compact vertical labeled icon menu" style="margin: 5px;">
        <a class="red item" href="{% url 'admin:djcms_blog_blog_change' object.id %}">
            <i class="edit icon"></i>{{edit_text}}</a>
        <a class="red item" href="{% url 'admin:djcms_blog_post_add' %}">
            <i class="plus icon"></i>{{add_post}}</a>
    </div>
</div>
{% endif %}