{% load i18n %}
<section class="share">
    <h3 class="ui right aligned header">{% trans "Share this post:" %}
        <a class="twitter" href="https://twitter.com/intent/tweet?text={{object.title}}&amp;url={{ request.build_absolute_uri }}"
            onclick="window.open(this.href, 'twitter-share', 'width=550,height=235');return false;">
            <i class="twitter icon"></i>
        </a>
        <a class="facebook" href="https://www.facebook.com/sharer/sharer.php?u={{ request.build_absolute_uri }}" onclick="window.open(this.href, 'facebook-share','width=580,height=296');return false;">
            <i class="facebook square icon"></i>
        </a>
        <a class="google-plus" href="https://plus.google.com/share?url={{ request.build_absolute_uri }}" onclick="window.open(this.href, 'google-plus-share', 'width=490,height=530');return false;">
            <i class="google plus square icon"></i>
        </a>
        <a class="linkedin" href="http://www.linkedin.com/shareArticle?mini=true&url={{ request.build_absolute_uri }}">
            <i class="linkedin icon"></i>
        </a>
    </h3>
</section>