{% extends "djcms_blog/base_author.html" %}
{% load i18n %}

{% block title %}
{{object.user.first_name}} {{object.user.last_name}}
{% endblock %}

{% block content %}
<section class="author-profile">
    <figure class="author-image">
        <img class="img" src="{{object.image.url}}">
    </figure>
    <div class="author-meta">
        <span class="author-location">
            <i class="map marker icon"></i>{{object.location}}</span>
        <span class="author-link">
            <a href="{{object.website}}"><i class="fas fa-link"></i>{{object.website}}</a>
        </span>
        <span class="author-social">
            <a href="{{object.facebook_profile}}">
                <i class="facebook square icon"></i>
            </a>
            <a href="{{object.twitter_profile}}">
                <i class="twitter icon"></i>
            </a>
            <a href="{{object.linkedin_profile}}">
                <i class="linkedin icon"></i>
            </a>
        </span>
        <span class="author-stats">
            <i class="signal icon"></i>{{object.get_post_count}} {% trans "posts"%}</span>
        
        {% if object.bio %}
        <p class="author-bio">{{object.bio}}</p>
        {% endif %}
    </div>
    
    <h4 class="ui horizontal divider header">
        <i class="file icon"></i>{% trans "Posts"%}
    </h4>
</section>
<section class="posts">
{% include "djcms_blog/post_list.html" %}
</section>
{% endblock content %}